@@ -1,10 +1,10 @@
-package App::ListDebianReleases;
+package App::ListUbuntuReleases;
 
 our $DATE = '2015-09-22'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 1;
-# ABSTRACT: List Debian releases (CLI)
+# ABSTRACT: List Ubuntu releases (CLI)
 
 __END__
 
@@ -14,15 +14,15 @@ __END__
 
 =head1 NAME
 
-App::ListDebianReleases - List Debian releases (CLI)
+App::ListUbuntuReleases - List Ubuntu releases (CLI)
 
 =head1 VERSION
 
-This document describes version 0.05 of App::ListDebianReleases (from Perl distribution App-ListUbuntuReleases), released on 2015-09-22.
+This document describes version 0.06 of App::ListUbuntuReleases (from Perl distribution App-ListUbuntuReleases), released on 2015-09-22.
 
 =head1 DESCRIPTION
 
-See the included script L<list-debian-releases>.
+See the included script L<list-ubuntu-releases>.
 
 =head1 HOMEPAGE
 
